==> catocli-2.1.4.tar.gz: catocli-2.1.4/catocli/parsers/query_auditFeed/__init__.py <==

from ..customParserApiClient import createRequest, get_help

def query_auditFeed_parse(query_subparsers):
    query_auditFeed_parser = query_subparsers.add_parser('auditFeed', 
            help='auditFeed() query operation', 
            usage=get_help("query_auditFeed"))

    query_auditFeed_parser.add_argument('json', nargs='?', default='{}', help='Variables in JSON format (defaults to empty object if not provided).')
    query_auditFeed_parser.add_argument('-accountID', help='The cato account ID to use for this operation. Overrides the account_id value in the profile setting.  This is use for reseller and MSP accounts to run queries against cato sub accounts from the parent account.')
    query_auditFeed_parser.add_argument('-t', const=True, default=False, nargs='?', help='Print GraphQL query without sending API call')
    query_auditFeed_parser.add_argument('-v', const=True, default=False, nargs='?', help='Verbose output')
    query_auditFeed_parser.add_argument('-p', const=True, default=False, nargs='?', help='Pretty print')
    query_auditFeed_parser.add_argument('-n', '--stream-events', dest='stream_events', help='Send events over network to host:port TCP')
    query_auditFeed_parser.add_argument('-z', '--sentinel', dest='sentinel', help='Send events to Sentinel customerid:sharedkey')
    query_auditFeed_parser.add_argument('-H', '--header', action='append', dest='headers', help='Add custom headers in "Key: Value" format. Can be used multiple times.')
    query_auditFeed_parser.add_argument('--headers-file', dest='headers_file', help='Load headers from a file. Each line should contain a header in "Key: Value" format.')
    query_auditFeed_parser.set_defaults(func=createRequest,operation_name='query.auditFeed')

==> catocli-3.0.36.tar.gz: catocli-3.0.36/catocli/parsers/query_auditFeed/__init__.py <==

from ..customParserApiClient import createRequest, get_help
from ...Utils.help_formatter import CustomSubparserHelpFormatter

def query_auditFeed_parse(query_subparsers):
    query_auditFeed_parser = query_subparsers.add_parser('auditFeed', 
            help='auditFeed() query operation', 
            usage=get_help("query_auditFeed"), formatter_class=CustomSubparserHelpFormatter)

    query_auditFeed_parser.add_argument('json', nargs='?', default='{}', help='Variables in JSON format (defaults to empty object if not provided).')
    query_auditFeed_parser.add_argument('-accountID', help='The cato account ID to use for this operation. Overrides the account_id value in the profile setting.  This is use for reseller and MSP accounts to run queries against cato sub accounts from the parent account.')
    query_auditFeed_parser.add_argument('-t', const=True, default=False, nargs='?', help='Print GraphQL query without sending API call')
    query_auditFeed_parser.add_argument('-v', const=True, default=False, nargs='?', help='Verbose output')
    query_auditFeed_parser.add_argument('-p', const=True, default=False, nargs='?', help='Pretty print')
    query_auditFeed_parser.add_argument('-n', '--stream-events', dest='stream_events', help='Send events over network to host:port TCP')
    query_auditFeed_parser.add_argument('-z', '--sentinel', dest='sentinel', help='Send events to Sentinel customerid:sharedkey')
    query_auditFeed_parser.add_argument('-H', '--header', action='append', dest='headers', help='Add custom headers in "Key: Value" format. Can be used multiple times.')
    query_auditFeed_parser.add_argument('--headers-file', dest='headers_file', help='Load headers from a file. Each line should contain a header in "Key: Value" format.')
    query_auditFeed_parser.add_argument('--trace-id', dest='trace_id', action='store_true', help='Enable tracing and print the trace ID from the response')
    query_auditFeed_parser.set_defaults(func=createRequest,operation_name='query.auditFeed')
